Changelog — Django Google Mailer 0.2.1 documentation

# Changelog

## 0.2.1 (2020-11-05)

### Updates

- Updated readme file

- Updated pypi setup file

### Fixes

- Fixed readthedocs config

## 0.2.0 (2020-11-05)

### Updates

- Updated urls for development

- Updated requirements file

- Added module documentation

### Fixes

- Removed url generation

- Fixed command logging in Makefile

- Redirection fixed in views

## 0.1.0 (2020-11-04)

### New Features

- Added basic OAuth authentication

- Added URL generation

- Added Code verification

- Added revoking functionality

- Created send mail and test mail functionalities

- Created development environment

- Created test environment

- Added documentation settings

### Updates

- Updated structure of Django settings

- Updated and restructed requirement.txt

- Converted Django app in to pip package

- Updated readme file